summaryrefslogtreecommitdiffhomepage
path: root/src/rcore_web.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/rcore_web.c')
-rw-r--r--src/rcore_web.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/rcore_web.c b/src/rcore_web.c
index 71e818ea..34836b7f 100644
--- a/src/rcore_web.c
+++ b/src/rcore_web.c
@@ -659,6 +659,7 @@ void SetMousePosition(int x, int y)
// Set mouse cursor
void SetMouseCursor(int cursor)
{
+ CORE.Input.Mouse.cursor = cursor;
const char *cursorName;
switch (cursor)
{
@@ -682,11 +683,13 @@ void SetMouseCursor(int cursor)
{
TRACELOG(LOG_WARNING, "Cursor value out of bound (%d). Setting to default", cursor);
cursorName = "default";
+ CORE.Input.Mouse.cursor = MOUSE_CURSOR_DEFAULT;
} break;
}
- // Set the cursor element on the CSS
- EM_ASM({document.body.style.cursor = UTF8ToString($0);}, cursorName);
+ // Set the cursor element on the canvas CSS
+ // The canvas is coded to the Id "canvas" on init
+ EM_ASM({document.getElementById("canvas").style.cursor = UTF8ToString($0);}, cursorName);
}
// Register all input events